package
module
Version:
v2.0.2
Opens a new window with list of versions in this module.
Published: Feb 6, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
GO Examples
a collection of go examples. see more at GO Docs
Use this mod
main.go
package main
import (
"gitee.com/egu0/goexamples/v2"
)
func main() {
println(goexamples.Greeting("Eugene"))
}
then run go mod tidy to download the package.
the run go run main.go
记录
- 仓库地址是:
https://gitee.com/egu0/goexamples
go.mod 第一行是:package gitee.com/egu0/goexamples/v2
- 在【仓库页面】创建 tag 和发行版:
v2.0.1
Documentation
¶
Hello returns a greeting for the named person.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.